### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

### [1.0.0](https://github.com/hemna/aprsd-webchat-extension/compare/v0.1.0...1.0.0)

> 10 December 2024

- Initial commit. [`d1ec549`](https://github.com/hemna/aprsd-webchat-extension/commit/d1ec5493e016ba72f1aba42b39ea83ef9760f045)
- More updates [`c28d677`](https://github.com/hemna/aprsd-webchat-extension/commit/c28d6772ae10ab880635f81e38c520f9c64e7e74)
- Get content to work again [`f5ce4a6`](https://github.com/hemna/aprsd-webchat-extension/commit/f5ce4a6646f894877c86ef00ac56377de868ec90)
- Added Changelog makefile [`591d6a1`](https://github.com/hemna/aprsd-webchat-extension/commit/591d6a1712cca9f3adaa0a3775ff0b3dde99fb82)

#### v0.1.0

> 9 December 2024

- Initial commit [`ced0b12`](https://github.com/hemna/aprsd-webchat-extension/commit/ced0b12fb81e875646bd6554696763491ae0cd58)
